//
//  EnvironmentTest.cpp
//
//  Created  by Setsu on 6/24/10.
//  Modified by Setsu on May 30, 2013.
//  Copyright 2010-2013 RoundSquare Inc. All rights reserved.
//
// Permission is hereby granted, free of charge, to any person or organization
// obtaining a copy of the software and accompanying documentation covered by
// this license (the "Software") to use, reproduce, display, distribute,
// execute, and transmit the Software, and to prepare derivative works of the
// Software, and to permit third-parties to whom the Software is furnished to
// do so, all subject to the following:
// 
// The copyright notices in the Software and this entire statement, including
// the above license grant, this restriction and the following disclaimer,
// must be included in all copies of the Software, in whole or in part, and
// all derivative works of the Software, unless such copies or derivative
// works are solely in the form of machine-executable object code generated by
// a source language processor.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
// SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
// FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

//----------------------------------------
//	include
//----------------------------------------
#include <Poco/Environment.h>
#include <Poco/Format.h>

#include <string>

#include "ScopedLogMessage.h"
#include "PrepareConsoleLogger.h"

//----------------------------------------
//	const
//----------------------------------------
const std::string kShellStr("SHELL");
const std::string kNotExistStr("NOT_EXIST");
const std::string kNotExistDefaultStr("NOT_EXIST_DEFAULT");
const std::string kManPathStr("MANPATH");

//----------------------------------------
//	main
//----------------------------------------
int main(int /*argc*/, char** /*argv*/)
{
	PrepareConsoleLogger logger(Poco::Logger::ROOT, Poco::Message::PRIO_INFORMATION);

	ScopedLogMessage msg("EnvironmentTest ", "start", "end");

	// Poco::Environment::get
	try
	{
		msg.Message(Poco::format("          %s: %s"
									, kShellStr
									, Poco::Environment::get(kShellStr)));
	}
	catch(Poco::NotFoundException& exc)
	{
		msg.Message(exc.displayText());
	}
	msg.Message(Poco::format("      %s: %s"
									, kNotExistStr
									, Poco::Environment::get(kNotExistStr, kNotExistDefaultStr)));

	// Poco::Environment::has
	msg.Message(Poco::format("    has %s: %s", kManPathStr, std::string(Poco::Environment::has(kManPathStr) ? "yes":"no")));

	// Poco::Environment::nodeId
	try
	{
		Poco::Environment::NodeId nodeId;
		Poco::Environment::nodeId(nodeId);
		msg.Message(Poco::format("         nodeId: %02?x:%02?x:%02?x:%02?x:%02?x:%02?x"
									, nodeId[0]
									, nodeId[1]
									, nodeId[2]
									, nodeId[3]
									, nodeId[4]
									, nodeId[5]));
	}
	catch(Poco::SystemException& exc)
	{
		msg.Message(exc.displayText());
	}
	msg.Message(Poco::format("         nodeId: %s"
									, Poco::Environment::nodeId()));

	// Poco::Environment::nodeName
	msg.Message(Poco::format("       nodeName: %s"
									, Poco::Environment::nodeName()));

	// Poco::Environment::osArchitecture
	msg.Message(Poco::format(" osArchitecture: %s"
									, Poco::Environment::osArchitecture()));

	// Poco::Environment::osName
	msg.Message(Poco::format("         osName: %s"
									, Poco::Environment::osName()));

	// Poco::Environment::osVersion
	msg.Message(Poco::format("      osVersion: %s"
									, Poco::Environment::osVersion()));

	// Poco::Environment::processorCount
	msg.Message(Poco::format(" processorCount: %u"
									, Poco::Environment::processorCount()));

	return 0;
}
